@@ -16,4 +16,7 @@ def palindrome(word):
     if word == reversedword:
         return(f"{word} is a palindrome")
     else:
-        return(f"{word} is not a palindrome")
\ No newline at end of file
+        return(f"{word} is not a palindrome")
+
+def remove_spaces(field):
+    return(field.replace(" ",""))
\ No newline at end of file
